#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_BITS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_BITS_HPP_INCLUDED

#include <boost/simd/bitwise/include/functions/bits.hpp>

#endif
